From 9994de85fcf14a98dcc54cc7399b87e34d9b3c29 Mon Sep 17 00:00:00 2001
From: tbrehm <t.brehm@ispconfig.org>
Date: Tue, 17 Mar 2009 09:23:07 -0400
Subject: [PATCH] Updated all language files.
---
interface/web/dns/dns_soa_edit.php | 29 +++++++++++++++++++----------
1 files changed, 19 insertions(+), 10 deletions(-)
diff --git a/interface/web/dns/dns_soa_edit.php b/interface/web/dns/dns_soa_edit.php
index 0526e5e..24ff164 100644
--- a/interface/web/dns/dns_soa_edit.php
+++ b/interface/web/dns/dns_soa_edit.php
@@ -1,4 +1,5 @@
<?php
+
/*
Copyright (c) 2007, Till Brehm, projektfarm Gmbh
All rights reserved.
@@ -27,7 +28,6 @@
EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
-
/******************************************
* Begin Form configuration
******************************************/
@@ -41,14 +41,11 @@
require_once('../../lib/config.inc.php');
require_once('../../lib/app.inc.php');
-// Checking module permissions
-if(!stristr($_SESSION["s"]["user"]["modules"],'dns')) {
- header("Location: ../index.php");
- exit;
-}
+//* Check permissions for module
+$app->auth->check_module_permissions('dns');
// Loading classes
-$app->uses('tpl,tform,tform_actions');
+$app->uses('tpl,tform,tform_actions,validate_dns');
$app->load('tform_actions');
class page_action extends tform_actions {
@@ -113,7 +110,7 @@
unset($tmp);
// When the record is inserted
} else {
- // set the server ID to the default mailserver of the client
+ // set the server ID to the default dnsserver of the client
$this->dataRecord["server_id"] = $client["default_dnsserver"];
// Check if the user may add another maildomain.
@@ -126,9 +123,21 @@
}
}
- // Set the serial
- $this->dataRecord["serial"] = time();
+ // Update the serial number of the SOA record
+ $soa = $app->db->queryOneRecord("SELECT serial FROM dns_soa WHERE id = ".$this->id);
+ $this->dataRecord["serial"] = $app->validate_dns->increase_serial($soa["serial"]);
+ //* Check if soa, ns and mbox have a dot at the end
+ if(substr($this->dataRecord["origin"],-1,1) != '.') $this->dataRecord["origin"] .= '.';
+ if(substr($this->dataRecord["ns"],-1,1) != '.') $this->dataRecord["ns"] .= '.';
+ if(substr($this->dataRecord["mbox"],-1,1) != '.') $this->dataRecord["mbox"] .= '.';
+
+ //* Replace @ in mbox
+ if(stristr($this->dataRecord["mbox"],'@')) {
+ $this->dataRecord["mbox"] = str_replace('@','.',$this->dataRecord["mbox"]);
+ }
+
+
parent::onSubmit();
}
--
Gitblit v1.9.1